summaryrefslogtreecommitdiff
path: root/innobase/include/sync0arr.h
diff options
context:
space:
mode:
Diffstat (limited to 'innobase/include/sync0arr.h')
-rw-r--r--innobase/include/sync0arr.h3
1 files changed, 1 insertions, 2 deletions
diff --git a/innobase/include/sync0arr.h b/innobase/include/sync0arr.h
index 765ad33afea..383d0c69fb2 100644
--- a/innobase/include/sync0arr.h
+++ b/innobase/include/sync0arr.h
@@ -114,8 +114,7 @@ Prints info of the wait array. */
void
sync_array_print_info(
/*==================*/
- char* buf, /* in/out: buffer where to print */
- char* buf_end,/* in: buffer end */
+ FILE* file, /* in: file where to print */
sync_array_t* arr); /* in: wait array */